"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processPageContent = processPageContent;
async function processPageContent(page, processors) {
  const processedContent = structuredClone(page.content);

  // Children of the root element of content contain elements of type "block".
  for (const block of processedContent.elements) {
    await traverse(block, async element => {
      for (const processor of processors) {
        await processor({
          page,
          block,
          element
        });
      }
    });
  }
  return {
    ...page,
    content: processedContent
  };
}
async function traverse(element, callback) {
  if (element.type !== "block") {
    await callback(element);
  }
  for (const child of element.elements || []) {
    await traverse(child, callback);
  }
}

//# sourceMappingURL=processPageContent.js.map